@@ -38,7 +38,7 @@ from monai.transforms import (
     EnsureTyped,
     EnsureType,
 )
-from unetr2d import UNETR2D
+from neurips_cellseg_gc.unetr2d import UNETR2D
 from monai.visualize import plot_2d_or_3d_image
 import matplotlib.pyplot as plt
 from datetime import datetime
@@ -52,9 +52,9 @@ print('Successfully import all requirements!')
 def main():
     parser = argparse.ArgumentParser('Baseline for Microscopy image segmentation', add_help=False)
     # Dataset parameters
-    parser.add_argument('--data_path', default='./data/Train_Pre_3class/', type=str,
+    parser.add_argument('--data_path', default='neurips_cellseg_gc/data/Train_Pre_3class/', type=str,
                         help='training data path; subfolders: images, labels')
-    parser.add_argument('--work_dir', default='./work_dir',
+    parser.add_argument('--work_dir', default='neurips_cellseg_gc/work_dir',
                         help='path where to save models and logs')
     parser.add_argument('--seed', default=2022, type=int)
     parser.add_argument('--resume', default=False,
@@ -62,7 +62,7 @@ def main():
     parser.add_argument('--num_workers', default=4, type=int)
 
     # Model parameters
-    parser.add_argument('--model_name', default='unet', help='select mode: unet, unetr, swinunetr')
+    parser.add_argument('--model_name', default='swinunetr', help='select mode: unet, unetr, swinunetr')
     parser.add_argument('--num_class', default=3, type=int, help='segmentation classes')
     parser.add_argument('--input_size', default=256, type=int, help='segmentation classes')
     # Training parameters
