@@ -6,7 +6,7 @@ import numpy as np
 import torch
 import monai
 from monai.inferers import sliding_window_inference
-from unetr2d import UNETR2D
+from neurips_cellseg_gc.unetr2d import UNETR2D
 import time
 from skimage import io, segmentation, morphology, measure, exposure
 import tifffile as tif
@@ -25,7 +25,7 @@ def main():
     # Dataset parameters
     parser.add_argument('-i', '--input_path', default='./inputs', type=str, help='training data path; subfolders: images, labels')
     parser.add_argument("-o", '--output_path', default='./outputs', type=str, help='output path')
-    parser.add_argument('--model_path', default='./work_dir/swinunetr_3class', help='path where to save models and segmentation results')
+    parser.add_argument('--model_path', default='neurips_cellseg_gc/work_dir/swinunetr_3class', help='path where to save models and segmentation results')
     parser.add_argument('--show_overlay', required=False, default=False, action="store_true", help='save segmentation overlay')
 
     # Model parameters
